@@ -7,7 +7,7 @@ pub enum MapReduceError<E> {
     Custom(E),
 }
 
-pub struct CtxWrapper<T: ?Sized> {
+pub(crate) struct CtxWrapper<T: ?Sized> {
     data: *const T,
 }
 
@@ -32,7 +32,7 @@ impl<T: ?Sized> CtxWrapper<T> {
     }
 }
 
-pub struct Worker<Resp> {
+pub(crate) struct Worker<Resp> {
     pub id: usize,
     pub thread: Box<JoinHandle<Resp>>,
 }
