@@ -1,6 +1,6 @@
-pub(crate) mod entities;
-pub(crate) mod managers;
+pub mod entities;
+pub mod managers;
 pub(crate) mod traits;
 
-pub use managers::{manager, Manager, MapManager, ReduceManager};
 pub use entities::MapReduceError;
+pub use managers::{manager, Manager, MapManager, ReduceManager};
